# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'guiscrcpy/ui/mainwindow.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(539, 629)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        MainWindow.setMinimumSize(QtCore.QSize(500, 420))
        font = QtGui.QFont()
        font.setFamily("Titillium Web")
        font.setPointSize(10)
        MainWindow.setFont(font)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/res/ui/guiscrcpy_logo.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MainWindow.setWindowIcon(icon)
        MainWindow.setStyleSheet("QPushButton {\n"
"border-radius: 10px;\n"
"    background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 255, 255, 255), stop:1 rgba(0, 255, 152, 255));\n"
"color: rgb(0, 0, 0);\n"
"}\n"
"QPushButton:pressed {\n"
"border-radius: 10px;\n"
"background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 255, 255, 255), stop:1 rgba(0, 255, 152, 255));\n"
"color: rgb(0, 0, 0);\n"
"}\n"
".QPushButton:hover {\n"
"border-radius: 10px;\n"
"    background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 199, 199, 255), stop:1 rgba(0, 190, 113, 255));\n"
"color: rgb(0, 0, 0);\n"
" }\n"
".QPushButton#quit{\n"
"                        background-color: qlineargradient(spread:pad, x1:0, y1:1, x2:1, y2:0, stop:0 rgba(255, 0, 0, 255), stop:1 rgba(255, 155, 0, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
" }\n"
".QPushButton#quit:hover{             \n"
"    background-color: qlineargradient(spread:pad, x1:0, y1:1, x2:1, y2:0, stop:0 rgba(172, 0, 0, 255), stop:1 rgba(175, 106, 0, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
" }\n"
".QPushButton#usbaud{\n"
"background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 0, 255, 255), stop:0.901961 rgba(152, 0, 255, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
"}\n"
".QPushButton#usbaud:hover{                        \n"
"    background-color: qlineargradient(spread:pad, x1:0, y1:1, x2:1, y2:0, stop:0 rgba(172, 0, 0, 255), stop:1 rgba(175, 106, 0, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
"}\n"
".QPushButton#mapnow{\n"
"background-color: qlineargradient(spread:pad, x1:0, y1:1, x2:1, y2:0, stop:0 rgba(253, 0, 255, 255), stop:0.990196 rgba(88, 0, 255, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
" }\n"
".QPushButton#initmapnow{\n"
"background-color: qlineargradient(spread:pad, x1:1, y1:1, x2:0, y2:0, stop:0.0196078 rgba(0, 141, 255, 255), stop:1 rgba(52, 0, 255, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
"}\n"
".QPushButton#initmapnow:hover{\n"
"background-color:qlineargradient(spread:pad, x1:1, y1:1, x2:0, y2:0, stop:0.0196078 rgba(0, 72, 131, 255), stop:1 rgba(24, 0, 122, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
" }\n"
".QPushButton#mapnow:hover{\n"
"background-color: qlineargradient(spread:pad, x1:0, y1:1, x2:1, y2:0, stop:0 rgba(199, 0, 255, 255), stop:0.990196 rgba(88, 0, 255, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
"}\n"
".QPushButton#network_button{\n"
"background-color: rgb(10, 10, 10);\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;    \n"
" }\n"
".QPushButton#settings_button{\n"
"background-color: rgb(10, 10, 10);\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;    \n"
" }\n"
".QPushButton#refreshdevices{\n"
"background-color: rgb(10, 10, 10);\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;    \n"
" }\n"
".QPushButton#restart_adb_server{\n"
"background-color: rgb(10, 10, 10);\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;    \n"
" }\n"
"\n"
"\n"
"\n"
"")
        MainWindow.setUnifiedTitleAndToolBarOnMac(False)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(24)
        sizePolicy.setVerticalStretch(25)
        sizePolicy.setHeightForWidth(self.centralwidget.sizePolicy().hasHeightForWidth())
        self.centralwidget.setSizePolicy(sizePolicy)
        self.centralwidget.setMinimumSize(QtCore.QSize(500, 300))
        self.centralwidget.setStyleSheet("")
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.frame = QtWidgets.QFrame(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy)
        self.frame.setObjectName("frame")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.frame)
        self.verticalLayout.setSizeConstraint(QtWidgets.QLayout.SetMaximumSize)
        self.verticalLayout.setContentsMargins(7, 1, 7, -1)
        self.verticalLayout.setObjectName("verticalLayout")
        self.gridLayout_4 = QtWidgets.QGridLayout()
        self.gridLayout_4.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.gridLayout_4.setVerticalSpacing(1)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.fullscreen = QtWidgets.QCheckBox(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.fullscreen.sizePolicy().hasHeightForWidth())
        self.fullscreen.setSizePolicy(sizePolicy)
        self.fullscreen.setMinimumSize(QtCore.QSize(10, 20))
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        self.fullscreen.setFont(font)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/icons/increase-size-option.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.fullscreen.setIcon(icon1)
        self.fullscreen.setObjectName("fullscreen")
        self.gridLayout_4.addWidget(self.fullscreen, 0, 4, 1, 1)
        self.aotop = QtWidgets.QCheckBox(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.aotop.sizePolicy().hasHeightForWidth())
        self.aotop.setSizePolicy(sizePolicy)
        self.aotop.setMinimumSize(QtCore.QSize(10, 20))
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        self.aotop.setFont(font)
        self.aotop.setToolTipDuration(2)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/icons/icons/fire-symbol.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.aotop.setIcon(icon2)
        self.aotop.setObjectName("aotop")
        self.gridLayout_4.addWidget(self.aotop, 1, 5, 1, 1)
        self.refreshdevices = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.refreshdevices.sizePolicy().hasHeightForWidth())
        self.refreshdevices.setSizePolicy(sizePolicy)
        self.refreshdevices.setMinimumSize(QtCore.QSize(22, 22))
        self.refreshdevices.setMaximumSize(QtCore.QSize(30, 16777215))
        self.refreshdevices.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/icons/icons/refresh-page-option.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.refreshdevices.setIcon(icon3)
        self.refreshdevices.setIconSize(QtCore.QSize(15, 15))
        self.refreshdevices.setObjectName("refreshdevices")
        self.gridLayout_4.addWidget(self.refreshdevices, 7, 2, 1, 1)
        self.check_swipe_panel = QtWidgets.QCheckBox(self.frame)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        self.check_swipe_panel.setFont(font)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/icons/icons/guiscrcpy_swipe_panel.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.check_swipe_panel.setIcon(icon4)
        self.check_swipe_panel.setObjectName("check_swipe_panel")
        self.gridLayout_4.addWidget(self.check_swipe_panel, 2, 0, 1, 4)
        self.showTouches = QtWidgets.QCheckBox(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.showTouches.sizePolicy().hasHeightForWidth())
        self.showTouches.setSizePolicy(sizePolicy)
        self.showTouches.setMinimumSize(QtCore.QSize(10, 20))
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        self.showTouches.setFont(font)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/icons/icons/hand-finger-pointing-down.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.showTouches.setIcon(icon5)
        self.showTouches.setObjectName("showTouches")
        self.gridLayout_4.addWidget(self.showTouches, 2, 4, 1, 1)
        self.recScui = QtWidgets.QCheckBox(self.frame)
        self.recScui.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.recScui.sizePolicy().hasHeightForWidth())
        self.recScui.setSizePolicy(sizePolicy)
        self.recScui.setMinimumSize(QtCore.QSize(10, 20))
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.recScui.setFont(font)
        self.recScui.setToolTipDuration(2)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/icons/icons/facetime-button.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.recScui.setIcon(icon6)
        self.recScui.setObjectName("recScui")
        self.gridLayout_4.addWidget(self.recScui, 0, 5, 1, 1)
        self.displayForceOn = QtWidgets.QCheckBox(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.displayForceOn.sizePolicy().hasHeightForWidth())
        self.displayForceOn.setSizePolicy(sizePolicy)
        self.displayForceOn.setMinimumSize(QtCore.QSize(10, 20))
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        self.displayForceOn.setFont(font)
        self.displayForceOn.setToolTipDuration(2)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/icons/icons/bullseye.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.displayForceOn.setIcon(icon7)
        self.displayForceOn.setObjectName("displayForceOn")
        self.gridLayout_4.addWidget(self.displayForceOn, 1, 4, 1, 1)
        self.lock_rotation = QtWidgets.QCheckBox(self.frame)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        self.lock_rotation.setFont(font)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/icons/icons/padlock.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.lock_rotation.setIcon(icon8)
        self.lock_rotation.setObjectName("lock_rotation")
        self.gridLayout_4.addWidget(self.lock_rotation, 2, 5, 1, 1)
        self.check_bottom_panel = QtWidgets.QCheckBox(self.frame)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        self.check_bottom_panel.setFont(font)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/icons/icons/guiscrcpy_bottom_panel.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.check_bottom_panel.setIcon(icon9)
        self.check_bottom_panel.setObjectName("check_bottom_panel")
        self.gridLayout_4.addWidget(self.check_bottom_panel, 0, 0, 1, 4)
        self.network_button = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.network_button.sizePolicy().hasHeightForWidth())
        self.network_button.setSizePolicy(sizePolicy)
        self.network_button.setToolTipDuration(2)
        self.network_button.setText("")
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/icons/icons/wifi.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.network_button.setIcon(icon10)
        self.network_button.setObjectName("network_button")
        self.gridLayout_4.addWidget(self.network_button, 7, 0, 1, 1)
        self.check_side_panel = QtWidgets.QCheckBox(self.frame)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        self.check_side_panel.setFont(font)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/icons/icons/guiscrcpy_side_panel.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.check_side_panel.setIcon(icon11)
        self.check_side_panel.setObjectName("check_side_panel")
        self.gridLayout_4.addWidget(self.check_side_panel, 1, 0, 1, 4)
        self.settings_button = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.settings_button.sizePolicy().hasHeightForWidth())
        self.settings_button.setSizePolicy(sizePolicy)
        self.settings_button.setText("")
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(":/icons/icons/gear.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.settings_button.setIcon(icon12)
        self.settings_button.setObjectName("settings_button")
        self.gridLayout_4.addWidget(self.settings_button, 7, 1, 1, 1)
        self.device_rotation = QtWidgets.QComboBox(self.frame)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(11)
        self.device_rotation.setFont(font)
        self.device_rotation.setObjectName("device_rotation")
        self.device_rotation.addItem("")
        self.device_rotation.addItem("")
        self.device_rotation.addItem("")
        self.device_rotation.addItem("")
        self.device_rotation.addItem("")
        self.gridLayout_4.addWidget(self.device_rotation, 7, 5, 1, 1)
        self.restart_adb_server = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.restart_adb_server.sizePolicy().hasHeightForWidth())
        self.restart_adb_server.setSizePolicy(sizePolicy)
        self.restart_adb_server.setMinimumSize(QtCore.QSize(22, 22))
        self.restart_adb_server.setMaximumSize(QtCore.QSize(30, 16777215))
        self.restart_adb_server.setToolTipDuration(2)
        self.restart_adb_server.setText("")
        self.restart_adb_server.setIcon(icon7)
        self.restart_adb_server.setIconSize(QtCore.QSize(15, 15))
        self.restart_adb_server.setObjectName("restart_adb_server")
        self.gridLayout_4.addWidget(self.restart_adb_server, 7, 3, 1, 1)
        self.verticalLayout.addLayout(self.gridLayout_4)
        self.devices_view = QtWidgets.QListWidget(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.devices_view.sizePolicy().hasHeightForWidth())
        self.devices_view.setSizePolicy(sizePolicy)
        self.devices_view.setMaximumSize(QtCore.QSize(16777215, 90))
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(9)
        self.devices_view.setFont(font)
        self.devices_view.setAutoFillBackground(True)
        self.devices_view.setStyleSheet("alternate-background-color: rgb(35, 35, 35);")
        self.devices_view.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.devices_view.setSizeAdjustPolicy(QtWidgets.QAbstractScrollArea.AdjustToContents)
        self.devices_view.setAutoScrollMargin(9)
        self.devices_view.setAlternatingRowColors(True)
        self.devices_view.setIconSize(QtCore.QSize(35, 35))
        self.devices_view.setTextElideMode(QtCore.Qt.ElideMiddle)
        self.devices_view.setProperty("isWrapping", False)
        self.devices_view.setResizeMode(QtWidgets.QListView.Adjust)
        self.devices_view.setViewMode(QtWidgets.QListView.IconMode)
        self.devices_view.setUniformItemSizes(True)
        self.devices_view.setBatchSize(100)
        self.devices_view.setItemAlignment(QtCore.Qt.AlignCenter)
        self.devices_view.setObjectName("devices_view")
        item = QtWidgets.QListWidgetItem()
        item.setTextAlignment(QtCore.Qt.AlignCenter)
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(":/icons/icons/android.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item.setIcon(icon13)
        self.devices_view.addItem(item)
        self.verticalLayout.addWidget(self.devices_view)
        self.private_message_box_adb = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.private_message_box_adb.sizePolicy().hasHeightForWidth())
        self.private_message_box_adb.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(11)
        self.private_message_box_adb.setFont(font)
        self.private_message_box_adb.setText("")
        self.private_message_box_adb.setObjectName("private_message_box_adb")
        self.verticalLayout.addWidget(self.private_message_box_adb)
        self.gridLayout_3 = QtWidgets.QGridLayout()
        self.gridLayout_3.setSpacing(0)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.dimensionDefaultCheckbox = QtWidgets.QCheckBox(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dimensionDefaultCheckbox.sizePolicy().hasHeightForWidth())
        self.dimensionDefaultCheckbox.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(11)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.dimensionDefaultCheckbox.setFont(font)
        self.dimensionDefaultCheckbox.setChecked(True)
        self.dimensionDefaultCheckbox.setObjectName("dimensionDefaultCheckbox")
        self.gridLayout_3.addWidget(self.dimensionDefaultCheckbox, 0, 3, 1, 2)
        self.label = QtWidgets.QLabel(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(11)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridLayout_3.addWidget(self.label, 0, 1, 1, 1)
        self.bitrateText = QtWidgets.QLineEdit(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bitrateText.sizePolicy().hasHeightForWidth())
        self.bitrateText.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Titillium Web")
        font.setPointSize(26)
        font.setBold(True)
        font.setWeight(75)
        self.bitrateText.setFont(font)
        self.bitrateText.setStyleSheet("color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
"\n"
"background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(0, 255, 255, 255), stop:1 rgba(0, 255, 0, 255));")
        self.bitrateText.setAlignment(QtCore.Qt.AlignCenter)
        self.bitrateText.setObjectName("bitrateText")
        self.gridLayout_3.addWidget(self.bitrateText, 2, 1, 1, 1)
        self.dial = QtWidgets.QDial(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dial.sizePolicy().hasHeightForWidth())
        self.dial.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(11)
        self.dial.setFont(font)
        self.dial.setCursor(QtGui.QCursor(QtCore.Qt.SizeHorCursor))
        self.dial.setToolTipDuration(2)
        self.dial.setStyleSheet("background-color: rgb(0, 255, 255);\n"
"color: rgb(255, 0, 127);\n"
"gridline-color: rgb(255, 0, 0);\n"
"selection-background-color: rgb(12, 255, 0);\n"
"\n"
"image: url(:/res/ui/guiscrcpy_logo.png);")
        self.dial.setMinimum(64)
        self.dial.setMaximum(16000)
        self.dial.setSingleStep(2)
        self.dial.setProperty("value", 8000)
        self.dial.setOrientation(QtCore.Qt.Horizontal)
        self.dial.setInvertedAppearance(False)
        self.dial.setInvertedControls(False)
        self.dial.setWrapping(False)
        self.dial.setNotchTarget(20.0)
        self.dial.setNotchesVisible(True)
        self.dial.setObjectName("dial")
        self.gridLayout_3.addWidget(self.dial, 0, 0, 4, 1)
        self.label_2 = QtWidgets.QLabel(self.frame)
        self.label_2.setText("")
        self.label_2.setObjectName("label_2")
        self.gridLayout_3.addWidget(self.label_2, 0, 5, 1, 1)
        self.dimensionSlider = QtWidgets.QSlider(self.frame)
        self.dimensionSlider.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dimensionSlider.sizePolicy().hasHeightForWidth())
        self.dimensionSlider.setSizePolicy(sizePolicy)
        self.dimensionSlider.setStyleSheet("color: rgb(255, 255, 255);")
        self.dimensionSlider.setMinimum(320)
        self.dimensionSlider.setMaximum(2048)
        self.dimensionSlider.setProperty("value", 1280)
        self.dimensionSlider.setOrientation(QtCore.Qt.Horizontal)
        self.dimensionSlider.setObjectName("dimensionSlider")
        self.gridLayout_3.addWidget(self.dimensionSlider, 3, 2, 1, 4)
        self.dimensionText = QtWidgets.QLineEdit(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dimensionText.sizePolicy().hasHeightForWidth())
        self.dimensionText.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Titillium Web")
        font.setPointSize(26)
        font.setBold(True)
        font.setWeight(75)
        self.dimensionText.setFont(font)
        self.dimensionText.setStyleSheet("color: rgb(255, 255, 255);\n"
"background-color: rgb(17, 17, 17);\n"
"border-radius: 10px;\n"
"")
        self.dimensionText.setInputMask("")
        self.dimensionText.setMaxLength(32767)
        self.dimensionText.setAlignment(QtCore.Qt.AlignCenter)
        self.dimensionText.setObjectName("dimensionText")
        self.gridLayout_3.addWidget(self.dimensionText, 2, 3, 1, 3)
        self.verticalLayout.addLayout(self.gridLayout_3)
        self.flaglineedit = QtWidgets.QLineEdit(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.flaglineedit.sizePolicy().hasHeightForWidth())
        self.flaglineedit.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Monospace")
        self.flaglineedit.setFont(font)
        self.flaglineedit.setObjectName("flaglineedit")
        self.verticalLayout.addWidget(self.flaglineedit)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setSpacing(5)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.quit = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.quit.sizePolicy().hasHeightForWidth())
        self.quit.setSizePolicy(sizePolicy)
        self.quit.setMinimumSize(QtCore.QSize(45, 45))
        self.quit.setToolTipDuration(2)
        self.quit.setStyleSheet("")
        self.quit.setText("")
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap(":/icons/icons/cross-mark-on-a-black-circle-background.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.quit.setIcon(icon14)
        self.quit.setObjectName("quit")
        self.horizontalLayout.addWidget(self.quit)
        self.pushButton = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton.sizePolicy().hasHeightForWidth())
        self.pushButton.setSizePolicy(sizePolicy)
        self.pushButton.setMinimumSize(QtCore.QSize(45, 45))
        font = QtGui.QFont()
        font.setFamily("Titillium Web")
        font.setPointSize(11)
        font.setBold(True)
        font.setWeight(75)
        self.pushButton.setFont(font)
        self.pushButton.setToolTipDuration(2)
        self.pushButton.setObjectName("pushButton")
        self.horizontalLayout.addWidget(self.pushButton)
        self.abtgit = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.abtgit.sizePolicy().hasHeightForWidth())
        self.abtgit.setSizePolicy(sizePolicy)
        self.abtgit.setMinimumSize(QtCore.QSize(45, 45))
        self.abtgit.setText("")
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap(":/icons/icons/github.logo.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.abtgit.setIcon(icon15)
        self.abtgit.setIconSize(QtCore.QSize(20, 20))
        self.abtgit.setObjectName("abtgit")
        self.horizontalLayout.addWidget(self.abtgit)
        self.usbaud = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(11)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.usbaud.sizePolicy().hasHeightForWidth())
        self.usbaud.setSizePolicy(sizePolicy)
        self.usbaud.setMinimumSize(QtCore.QSize(45, 45))
        self.usbaud.setText("")
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap(":/icons/icons/volume-up-interface-symbol.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.usbaud.setIcon(icon16)
        self.usbaud.setObjectName("usbaud")
        self.horizontalLayout.addWidget(self.usbaud)
        self.initmapnow = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(11)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.initmapnow.sizePolicy().hasHeightForWidth())
        self.initmapnow.setSizePolicy(sizePolicy)
        self.initmapnow.setMinimumSize(QtCore.QSize(45, 45))
        self.initmapnow.setToolTipDuration(3)
        self.initmapnow.setText("")
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(":/icons/icons/mapper_init.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.initmapnow.setIcon(icon17)
        self.initmapnow.setIconSize(QtCore.QSize(40, 40))
        self.initmapnow.setObjectName("initmapnow")
        self.horizontalLayout.addWidget(self.initmapnow)
        self.executeaction = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.executeaction.sizePolicy().hasHeightForWidth())
        self.executeaction.setSizePolicy(sizePolicy)
        self.executeaction.setMinimumSize(QtCore.QSize(45, 45))
        font = QtGui.QFont()
        font.setFamily("Titillium Web")
        font.setPointSize(11)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.executeaction.setFont(font)
        self.executeaction.setStyleSheet("")
        icon18 = QtGui.QIcon()
        icon18.addPixmap(QtGui.QPixmap(":/icons/icons/small-rocket-ship-silhouette.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.executeaction.setIcon(icon18)
        self.executeaction.setIconSize(QtCore.QSize(20, 16))
        self.executeaction.setObjectName("executeaction")
        self.horizontalLayout.addWidget(self.executeaction)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.progressBar = QtWidgets.QProgressBar(self.frame)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.WindowText, brush)
        gradient = QtGui.QLinearGradient(0.0, 0.0, 1.0, 0.0)
        gradient.setSpread(QtGui.QGradient.PadSpread)
        gradient.setCoordinateMode(QtGui.QGradient.ObjectBoundingMode)
        gradient.setColorAt(0.0, QtGui.QColor(0, 255, 255))
        gradient.setColorAt(1.0, QtGui.QColor(0, 255, 0))
        brush = QtGui.QBrush(gradient)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Text, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.ButtonText, brush)
        gradient = QtGui.QLinearGradient(0.0, 0.0, 1.0, 0.0)
        gradient.setSpread(QtGui.QGradient.PadSpread)
        gradient.setCoordinateMode(QtGui.QGradient.ObjectBoundingMode)
        gradient.setColorAt(0.0, QtGui.QColor(0, 255, 255))
        gradient.setColorAt(1.0, QtGui.QColor(0, 255, 0))
        brush = QtGui.QBrush(gradient)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Base, brush)
        gradient = QtGui.QLinearGradient(0.0, 0.0, 1.0, 0.0)
        gradient.setSpread(QtGui.QGradient.PadSpread)
        gradient.setCoordinateMode(QtGui.QGradient.ObjectBoundingMode)
        gradient.setColorAt(0.0, QtGui.QColor(0, 255, 255))
        gradient.setColorAt(1.0, QtGui.QColor(0, 255, 0))
        brush = QtGui.QBrush(gradient)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(85, 255, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Highlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.HighlightedText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255, 128))
        brush.setStyle(QtCore.Qt.NoBrush)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.PlaceholderText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.WindowText, brush)
        gradient = QtGui.QLinearGradient(0.0, 0.0, 1.0, 0.0)
        gradient.setSpread(QtGui.QGradient.PadSpread)
        gradient.setCoordinateMode(QtGui.QGradient.ObjectBoundingMode)
        gradient.setColorAt(0.0, QtGui.QColor(0, 255, 255))
        gradient.setColorAt(1.0, QtGui.QColor(0, 255, 0))
        brush = QtGui.QBrush(gradient)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Text, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ButtonText, brush)
        gradient = QtGui.QLinearGradient(0.0, 0.0, 1.0, 0.0)
        gradient.setSpread(QtGui.QGradient.PadSpread)
        gradient.setCoordinateMode(QtGui.QGradient.ObjectBoundingMode)
        gradient.setColorAt(0.0, QtGui.QColor(0, 255, 255))
        gradient.setColorAt(1.0, QtGui.QColor(0, 255, 0))
        brush = QtGui.QBrush(gradient)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Base, brush)
        gradient = QtGui.QLinearGradient(0.0, 0.0, 1.0, 0.0)
        gradient.setSpread(QtGui.QGradient.PadSpread)
        gradient.setCoordinateMode(QtGui.QGradient.ObjectBoundingMode)
        gradient.setColorAt(0.0, QtGui.QColor(0, 255, 255))
        gradient.setColorAt(1.0, QtGui.QColor(0, 255, 0))
        brush = QtGui.QBrush(gradient)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(85, 255, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Highlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.HighlightedText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255, 128))
        brush.setStyle(QtCore.Qt.NoBrush)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.PlaceholderText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.WindowText, brush)
        gradient = QtGui.QLinearGradient(0.0, 0.0, 1.0, 0.0)
        gradient.setSpread(QtGui.QGradient.PadSpread)
        gradient.setCoordinateMode(QtGui.QGradient.ObjectBoundingMode)
        gradient.setColorAt(0.0, QtGui.QColor(0, 255, 255))
        gradient.setColorAt(1.0, QtGui.QColor(0, 255, 0))
        brush = QtGui.QBrush(gradient)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Text, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ButtonText, brush)
        gradient = QtGui.QLinearGradient(0.0, 0.0, 1.0, 0.0)
        gradient.setSpread(QtGui.QGradient.PadSpread)
        gradient.setCoordinateMode(QtGui.QGradient.ObjectBoundingMode)
        gradient.setColorAt(0.0, QtGui.QColor(0, 255, 255))
        gradient.setColorAt(1.0, QtGui.QColor(0, 255, 0))
        brush = QtGui.QBrush(gradient)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Base, brush)
        gradient = QtGui.QLinearGradient(0.0, 0.0, 1.0, 0.0)
        gradient.setSpread(QtGui.QGradient.PadSpread)
        gradient.setCoordinateMode(QtGui.QGradient.ObjectBoundingMode)
        gradient.setColorAt(0.0, QtGui.QColor(0, 255, 255))
        gradient.setColorAt(1.0, QtGui.QColor(0, 255, 0))
        brush = QtGui.QBrush(gradient)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(85, 255, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Highlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.HighlightedText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255, 128))
        brush.setStyle(QtCore.Qt.NoBrush)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.PlaceholderText, brush)
        self.progressBar.setPalette(palette)
        font = QtGui.QFont()
        font.setFamily("Titillium Web")
        font.setPointSize(10)
        self.progressBar.setFont(font)
        self.progressBar.setStyleSheet("")
        self.progressBar.setProperty("value", 100)
        self.progressBar.setObjectName("progressBar")
        self.verticalLayout.addWidget(self.progressBar)
        self.gridLayout_5.addWidget(self.frame, 1, 0, 1, 1)
        self.frame1 = QtWidgets.QFrame(self.centralwidget)
        self.frame1.setObjectName("frame1")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.frame1)
        self.horizontalLayout_2.setSizeConstraint(QtWidgets.QLayout.SetMaximumSize)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_4 = QtWidgets.QLabel(self.frame1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_4.sizePolicy().hasHeightForWidth())
        self.label_4.setSizePolicy(sizePolicy)
        self.label_4.setMinimumSize(QtCore.QSize(60, 60))
        self.label_4.setMaximumSize(QtCore.QSize(60, 60))
        self.label_4.setText("")
        self.label_4.setPixmap(QtGui.QPixmap(":/res/ui/guiscrcpy_logo.png"))
        self.label_4.setScaledContents(True)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_2.addWidget(self.label_4)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setSizeConstraint(QtWidgets.QLayout.SetMaximumSize)
        self.verticalLayout_2.setSpacing(0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label_3 = QtWidgets.QLabel(self.frame1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_3.sizePolicy().hasHeightForWidth())
        self.label_3.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Titillium Web")
        font.setPointSize(28)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.label_3.setFont(font)
        self.label_3.setStyleSheet("")
        self.label_3.setObjectName("label_3")
        self.verticalLayout_2.addWidget(self.label_3)
        self.build_label = QtWidgets.QLabel(self.frame1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.build_label.sizePolicy().hasHeightForWidth())
        self.build_label.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        self.build_label.setFont(font)
        self.build_label.setStyleSheet("color: rgb(255, 255, 255);")
        self.build_label.setObjectName("build_label")
        self.verticalLayout_2.addWidget(self.build_label)
        self.horizontalLayout_2.addLayout(self.verticalLayout_2)
        self.gridLayout_5.addWidget(self.frame1, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        font = QtGui.QFont()
        font.setFamily("Titillium Web")
        font.setPointSize(10)
        self.statusbar.setFont(font)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "guiscrcpy"))
        MainWindow.setStatusTip(_translate("MainWindow", "GUI by srevinsaju, scrcpy engine by rom1v. Hosted on GitHub\n"
"                https://github.com/srevinsaju/guiscrcpy\n"
"            "))
        self.fullscreen.setText(_translate("MainWindow", "Fullscreen"))
        self.aotop.setToolTip(_translate("MainWindow", "Keep display always on top of other windows"))
        self.aotop.setText(_translate("MainWindow", "Always on Top"))
        self.check_swipe_panel.setText(_translate("MainWindow", "Swipe Panel"))
        self.showTouches.setText(_translate("MainWindow", "Show touches"))
        self.recScui.setToolTip(_translate("MainWindow", "<html><head/><body><p>Record your screen mirroring to your home directory. In Linux, it is in ~guiscrcpy directory. In Windows, it is in C:\\Users\\&lt;username&gt;\\ with the UNIX date, followed by .mp4; For manual configuration and path selection, use the settings icon</p></body></html>"))
        self.recScui.setStatusTip(_translate("MainWindow", "See tooltip"))
        self.recScui.setText(_translate("MainWindow", "Record screen"))
        self.displayForceOn.setToolTip(_translate("MainWindow", "Use your computer screen as your android device\'s HD Display"))
        self.displayForceOn.setText(_translate("MainWindow", "Keep display off "))
        self.lock_rotation.setText(_translate("MainWindow", "Lock Rotation"))
        self.check_bottom_panel.setText(_translate("MainWindow", "Bottom Panel"))
        self.network_button.setToolTip(_translate("MainWindow", "Launch Network Manager"))
        self.check_side_panel.setText(_translate("MainWindow", "Side Panel"))
        self.device_rotation.setItemText(0, _translate("MainWindow", "Default Rotation"))
        self.device_rotation.setItemText(1, _translate("MainWindow", "Potrait"))
        self.device_rotation.setItemText(2, _translate("MainWindow", "Landscape"))
        self.device_rotation.setItemText(3, _translate("MainWindow", "Potrait (flipped)"))
        self.device_rotation.setItemText(4, _translate("MainWindow", "Landscape (flipped)"))
        self.restart_adb_server.setToolTip(_translate("MainWindow", "Restart the adb-server"))
        self.devices_view.setSortingEnabled(True)
        __sortingEnabled = self.devices_view.isSortingEnabled()
        self.devices_view.setSortingEnabled(False)
        item = self.devices_view.item(0)
        item.setText(_translate("MainWindow", "Nothing here"))
        self.devices_view.setSortingEnabled(__sortingEnabled)
        self.dimensionDefaultCheckbox.setText(_translate("MainWindow", "Keep Default Dimensions"))
        self.label.setText(_translate("MainWindow", "Bitrate"))
        self.bitrateText.setInputMask(_translate("MainWindow", "00000 A\\B/s"))
        self.bitrateText.setText(_translate("MainWindow", "8000 KB/s"))
        self.dial.setToolTip(_translate("MainWindow", "Changing the bitrate of the screen mirrorring. Useful to show playback at normal speed without lags"))
        self.dial.setStatusTip(_translate("MainWindow", "Adjust Bitrate. Leave it untouched for defualts"))
        self.dimensionText.setText(_translate("MainWindow", "DEFAULT"))
        self.flaglineedit.setPlaceholderText(_translate("MainWindow", "Enter additional flags to pass to scrcpy"))
        self.quit.setStatusTip(_translate("MainWindow", "Quit GUI and end all subprocess windows "))
        self.pushButton.setStatusTip(_translate("MainWindow", "Reset guiscrcpy configuration files"))
        self.pushButton.setText(_translate("MainWindow", "  RESET  "))
        self.abtgit.setStatusTip(_translate("MainWindow", "Check me out on Github"))
        self.usbaud.setStatusTip(_translate("MainWindow", "Start @rom1v\'s usbaudio. Needs usbaudio to be on PATH"))
        self.initmapnow.setToolTip(_translate("MainWindow", "Initialize mapper"))
        self.initmapnow.setStatusTip(_translate("MainWindow", "Initialize mapper"))
        self.executeaction.setStatusTip(_translate("MainWindow", "Start Scrcpy Executable right now. Please check if Scrcpy is added to path"))
        self.executeaction.setText(_translate("MainWindow", "START SCRCPY"))
        self.progressBar.setStatusTip(_translate("MainWindow", "Progress Bar"))
        self.label_4.setToolTip(_translate("MainWindow", "GUI by srevinsaju, scrcpy engine by rom1v. Hosted on GitHub\n"
"                        https://github.com/srevinsaju/guiscrcpy\n"
"                    "))
        self.label_4.setStatusTip(_translate("MainWindow", "GUI by srevinsaju, scrcpy engine by rom1v. Hosted on GitHub\n"
"                        https://github.com/srevinsaju/guiscrcpy\n"
"                    "))
        self.label_3.setStatusTip(_translate("MainWindow", "GUI by srevinsaju, scrcpy engine by rom1v. Hosted on GitHub\n"
"                        https://github.com/srevinsaju/guiscrcpy\n"
"                    "))
        self.label_3.setText(_translate("MainWindow", "guiscrcpy                          "))
        self.build_label.setText(_translate("MainWindow", "Build"))
from . import rsrc_rc
