GUISCRCPY_DEVICE = \
    """[Desktop Entry]
Name={identifier}
GenericName=guiscrcpy
Comment=Open Source Android Screen Mirroring System
Exec={command}
Icon={icon_path}
Type=Application
Categories=Utility;Development;
StartupWMClass=UGENE
"""
